/** Copyright (C) 2017 by Bundesanstalt für Gewässerkunde
 * Software engineering by
 *  Björnsen Beratende Ingenieure GmbH
 *  Dr. Schumacher Ingenieurbüro für Wasser und Umwelt
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */
package test.sinfo;

import java.io.IOException;

import org.dive4elements.artifacts.httpclient.exceptions.ConnectionException;
import org.dive4elements.river.client.shared.exceptions.ServerException;
import org.dive4elements.river.client.shared.model.Data;
import org.dive4elements.river.client.shared.model.DataItem;
import org.dive4elements.river.client.shared.model.DefaultDataItem;
import org.dive4elements.river.client.shared.model.StringOptionsData;

import test.AbstractBerechnungsartenTester.River;
import test.AbstractModuleRunner;
import test.ICalcMode;
import test.WQInputHelper;
import test.sinfo.SinfoFloodDurationRiversideChoice.RiversideChoiceKey;

/**
 * @author Domenico Nardi Tironi
 *
 */
final class SinfoFloodDurationRunner extends AbstractModuleRunner {

    private final double[] wasserspiegellage;
    private final boolean showWspl;
    private final RiversideChoiceKey riverside;

    public SinfoFloodDurationRunner(final ICalcMode calcmode, final double from, final double to, final River river, final double[] wasserspiegellage,
            final RiversideChoiceKey riverside, final boolean showWspl) throws ConnectionException, ServerException {
        super(AbstractModuleRunner.Infotype.sinfo, calcmode, from, to, river);
        this.wasserspiegellage = wasserspiegellage;
        this.showWspl = showWspl;
        this.riverside = riverside;
    }

    @Override
    public void runTest() throws ServerException, IOException {
        /* Select River */
        super.selectRiver();

        /* Select ICalcMode */
        super.selectCalcMode();

        super.feed(new Data[] {
                new StringOptionsData("ld_mode", "ld_mode", new DataItem[] { new DefaultDataItem("distance_only", "distance_only", "distance_only") }) }); //

        /* Select Range */
        super.selectRange();

        final Data riversideData = new StringOptionsData("riverside", "riverside",
                new DataItem[] { new DefaultDataItem("riverside", "riverside", this.riverside.toString()) });
        feedAndGo(new Data[] { riversideData }, 0);

        final Data showWsplData = new StringOptionsData("wspl", "wspl", new DataItem[] { new DefaultDataItem("wspl", "wspl", String.valueOf(this.showWspl)) });
        feedAndGo(new Data[] { showWsplData }, 0);

        if (this.showWspl) {
            final WQInputHelper helper = new WQInputHelper(this.wasserspiegellage);
            super.feedAndGo(helper.getDataforFeed(), //
                    0);// reachable state index
        }

        describeCollection();

        super.runTests();
    }
}
